# $Id: StrainSegGenerator.py,v 1.1 2005/11/06 18:32:13 kipp Exp $

#
# Preamble.
#

import glob

from glue import lal
from glue import segmentsUtils
from onasys import LSCsegFindSegGenerator

#
# A segment generator for the h(t) pipeline.  This segment generator is a
# modification of the LSCsegFindSegGenerator that adds a check for the
# filter history files.
#
# How to use this.  This segment generator plug-in has a [seggenerator]
# section in the .ini file whose contents are identical to the
# [seggenerator] section used by the LSCsegFindSegGenerator plug-in, with
# one additional required configuration variable:  "filter_histories",
# which should be set to a shell path pattern to be used to search for
# filter history files.
#
# The list of filter history file names is turned into a list of segments
# whose starts mark the starts of segments for which those files should be
# used as the history.  This segment list is returned to the daemon as the
# segmentlist "filterhistories" in the segmentlist dictionary.
#

class SegGeneratorConfig(LSCsegFindSegGenerator.SegGeneratorConfig):
	def parse(self):
		LSCsegFindSegGenerator.SegGeneratorConfig.parse(self)
		self.filter_histories = self.parser.get(self.section, "filter_histories")


class SegGenerator(LSCsegFindSegGenerator.SegGenerator):
	def generate(self, available, clock):
		# first chain to LSCsegFindSegGenerator
		result = LSCsegFindSegGenerator.SegGenerator.generate(self, available, clock)

		# now get list of filter history files
		result["filterhistories"] = segmentsUtils.fromfilenames(glob.glob(self.config.filter_histories), coltype=lal.LIGOTimeGPS)

		return result
